@@ -1,7 +1,7 @@
 from .__version__ import __version__
 from . import mixins
 from .exceptions import ValidationError
-from .dom.functions import dom, document, parent, key
+from .dom import document, parent, key, schema
 from .dom import DOMInfo as DOMInfo
 from .dom import DOMElement as Element
 from .base_schema import Schema, SchemaAnything, SchemaConst
